Class: Google::Apis::ServiceconsumermanagementV1::ClientLibrarySettings
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::ClientLibrarySettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
Details about how and where to publish client libraries.
Instance Attribute Summary collapse
-
#cpp_settings ⇒ Google::Apis::ServiceconsumermanagementV1::CppSettings
Settings for C++ client libraries.
-
#dotnet_settings ⇒ Google::Apis::ServiceconsumermanagementV1::DotnetSettings
Settings for Dotnet client libraries.
-
#go_settings ⇒ Google::Apis::ServiceconsumermanagementV1::GoSettings
Settings for Go client libraries.
-
#java_settings ⇒ Google::Apis::ServiceconsumermanagementV1::JavaSettings
Settings for Java client libraries.
-
#launch_stage ⇒ String
Launch stage of this version of the API.
-
#node_settings ⇒ Google::Apis::ServiceconsumermanagementV1::NodeSettings
Settings for Node client libraries.
-
#php_settings ⇒ Google::Apis::ServiceconsumermanagementV1::PhpSettings
Settings for Php client libraries.
-
#python_settings ⇒ Google::Apis::ServiceconsumermanagementV1::PythonSettings
Settings for Python client libraries.
-
#rest_numeric_enums ⇒ Boolean
(also: #rest_numeric_enums?)
When using transport=rest, the client request will encode enums as numbers rather than strings.
-
#ruby_settings ⇒ Google::Apis::ServiceconsumermanagementV1::RubySettings
Settings for Ruby client libraries.
-
#version ⇒ String
Version of the API to apply these settings to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClientLibrarySettings
constructor
A new instance of ClientLibrarySettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClientLibrarySettings
Returns a new instance of ClientLibrarySettings.
883 884 885 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpp_settings ⇒ Google::Apis::ServiceconsumermanagementV1::CppSettings
Settings for C++ client libraries.
Corresponds to the JSON property cppSettings
827 828 829 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 827 def cpp_settings @cpp_settings end |
#dotnet_settings ⇒ Google::Apis::ServiceconsumermanagementV1::DotnetSettings
Settings for Dotnet client libraries.
Corresponds to the JSON property dotnetSettings
832 833 834 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 832 def dotnet_settings @dotnet_settings end |
#go_settings ⇒ Google::Apis::ServiceconsumermanagementV1::GoSettings
Settings for Go client libraries.
Corresponds to the JSON property goSettings
837 838 839 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 837 def go_settings @go_settings end |
#java_settings ⇒ Google::Apis::ServiceconsumermanagementV1::JavaSettings
Settings for Java client libraries.
Corresponds to the JSON property javaSettings
842 843 844 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 842 def java_settings @java_settings end |
#launch_stage ⇒ String
Launch stage of this version of the API.
Corresponds to the JSON property launchStage
847 848 849 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 847 def launch_stage @launch_stage end |
#node_settings ⇒ Google::Apis::ServiceconsumermanagementV1::NodeSettings
Settings for Node client libraries.
Corresponds to the JSON property nodeSettings
852 853 854 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 852 def node_settings @node_settings end |
#php_settings ⇒ Google::Apis::ServiceconsumermanagementV1::PhpSettings
Settings for Php client libraries.
Corresponds to the JSON property phpSettings
857 858 859 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 857 def php_settings @php_settings end |
#python_settings ⇒ Google::Apis::ServiceconsumermanagementV1::PythonSettings
Settings for Python client libraries.
Corresponds to the JSON property pythonSettings
862 863 864 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 862 def python_settings @python_settings end |
#rest_numeric_enums ⇒ Boolean Also known as: rest_numeric_enums?
When using transport=rest, the client request will encode enums as numbers
rather than strings.
Corresponds to the JSON property restNumericEnums
868 869 870 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 868 def rest_numeric_enums @rest_numeric_enums end |
#ruby_settings ⇒ Google::Apis::ServiceconsumermanagementV1::RubySettings
Settings for Ruby client libraries.
Corresponds to the JSON property rubySettings
874 875 876 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 874 def ruby_settings @ruby_settings end |
#version ⇒ String
Version of the API to apply these settings to. This is the full protobuf
package for the API, ending in the version element. Examples: "google.cloud.
speech.v1" and "google.spanner.admin.database.v1".
Corresponds to the JSON property version
881 882 883 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 881 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
888 889 890 891 892 893 894 895 896 897 898 899 900 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 888 def update!(**args) @cpp_settings = args[:cpp_settings] if args.key?(:cpp_settings) @dotnet_settings = args[:dotnet_settings] if args.key?(:dotnet_settings) @go_settings = args[:go_settings] if args.key?(:go_settings) @java_settings = args[:java_settings] if args.key?(:java_settings) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @node_settings = args[:node_settings] if args.key?(:node_settings) @php_settings = args[:php_settings] if args.key?(:php_settings) @python_settings = args[:python_settings] if args.key?(:python_settings) @rest_numeric_enums = args[:rest_numeric_enums] if args.key?(:rest_numeric_enums) @ruby_settings = args[:ruby_settings] if args.key?(:ruby_settings) @version = args[:version] if args.key?(:version) end |