Class: Google::Apis::ServiceconsumermanagementV1::CreateTenancyUnitRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::CreateTenancyUnitRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
Request to create a tenancy unit for a service consumer of a managed service.
Instance Attribute Summary collapse
-
#tenancy_unit_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateTenancyUnitRequest
constructor
A new instance of CreateTenancyUnitRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateTenancyUnitRequest
Returns a new instance of CreateTenancyUnitRequest.
1080 1081 1082 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tenancy_unit_id ⇒ String
Optional. Optional service producer-provided identifier of the tenancy unit.
Must be no longer than 40 characters and preferably URI friendly. If it isn't
provided, a UID for the tenancy unit is automatically generated. The
identifier must be unique across a managed service. If the tenancy unit
already exists for the managed service and service consumer pair, calling
CreateTenancyUnit returns the existing tenancy unit if the provided
identifier is identical or empty, otherwise the call fails.
Corresponds to the JSON property tenancyUnitId
1078 1079 1080 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1078 def tenancy_unit_id @tenancy_unit_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1085 1086 1087 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1085 def update!(**args) @tenancy_unit_id = args[:tenancy_unit_id] if args.key?(:tenancy_unit_id) end |