Class: Google::Apis::ServiceconsumermanagementV1::DotnetSettings
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::DotnetSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
Settings for Dotnet client libraries.
Instance Attribute Summary collapse
-
#common ⇒ Google::Apis::ServiceconsumermanagementV1::CommonLanguageSettings
Required information for every language.
-
#forced_namespace_aliases ⇒ Array<String>
Namespaces which must be aliased in snippets due to a known (but non-generator- predictable) naming collision Corresponds to the JSON property
forcedNamespaceAliases. -
#handwritten_signatures ⇒ Array<String>
Method signatures (in the form "service.method(signature)") which are provided separately, so shouldn't be generated.
-
#ignored_resources ⇒ Array<String>
List of full resource types to ignore during generation.
-
#renamed_resources ⇒ Hash<String,String>
Map from full resource types to the effective short name for the resource.
-
#renamed_services ⇒ Hash<String,String>
Map from original service names to renamed versions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DotnetSettings
constructor
A new instance of DotnetSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DotnetSettings
Returns a new instance of DotnetSettings.
1377 1378 1379 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1377 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common ⇒ Google::Apis::ServiceconsumermanagementV1::CommonLanguageSettings
Required information for every language.
Corresponds to the JSON property common
1339 1340 1341 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1339 def common @common end |
#forced_namespace_aliases ⇒ Array<String>
Namespaces which must be aliased in snippets due to a known (but non-generator-
predictable) naming collision
Corresponds to the JSON property forcedNamespaceAliases
1345 1346 1347 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1345 def forced_namespace_aliases @forced_namespace_aliases end |
#handwritten_signatures ⇒ Array<String>
Method signatures (in the form "service.method(signature)") which are provided
separately, so shouldn't be generated. Snippets calling these methods are
still generated, however.
Corresponds to the JSON property handwrittenSignatures
1352 1353 1354 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1352 def handwritten_signatures @handwritten_signatures end |
#ignored_resources ⇒ Array<String>
List of full resource types to ignore during generation. This is typically
used for API-specific Location resources, which should be handled by the
generator as if they were actually the common Location resources. Example
entry: "documentai.googleapis.com/Location"
Corresponds to the JSON property ignoredResources
1360 1361 1362 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1360 def ignored_resources @ignored_resources end |
#renamed_resources ⇒ Hash<String,String>
Map from full resource types to the effective short name for the resource.
This is used when otherwise resource named from different services would cause
naming collisions. Example entry: "datalabeling.googleapis.com/Dataset": "
DataLabelingDataset"
Corresponds to the JSON property renamedResources
1368 1369 1370 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1368 def renamed_resources @renamed_resources end |
#renamed_services ⇒ Hash<String,String>
Map from original service names to renamed versions. This is used when the
default generated types would cause a naming conflict. (Neither name is fully-
qualified.) Example: Subscriber to SubscriberServiceApi.
Corresponds to the JSON property renamedServices
1375 1376 1377 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1375 def renamed_services @renamed_services end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1382 1383 1384 1385 1386 1387 1388 1389 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1382 def update!(**args) @common = args[:common] if args.key?(:common) @forced_namespace_aliases = args[:forced_namespace_aliases] if args.key?(:forced_namespace_aliases) @handwritten_signatures = args[:handwritten_signatures] if args.key?(:handwritten_signatures) @ignored_resources = args[:ignored_resources] if args.key?(:ignored_resources) @renamed_resources = args[:renamed_resources] if args.key?(:renamed_resources) @renamed_services = args[:renamed_services] if args.key?(:renamed_services) end |