Class: Google::Apis::ServiceconsumermanagementV1::EnumValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnumValue

Returns a new instance of EnumValue.



1546
1547
1548
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1546

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Enum value name. Corresponds to the JSON property name

Returns:

  • (String)


1534
1535
1536
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1534

def name
  @name
end

#numberFixnum

Enum value number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


1539
1540
1541
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1539

def number
  @number
end

#optionsArray<Google::Apis::ServiceconsumermanagementV1::Option>

Protocol buffer options. Corresponds to the JSON property options



1544
1545
1546
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1544

def options
  @options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1551
1552
1553
1554
1555
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1551

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @options = args[:options] if args.key?(:options)
end