Class: Google::Apis::ServiceconsumermanagementV1::Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

A single field of a message type. New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



1662
1663
1664
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1662

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

The field cardinality. Corresponds to the JSON property cardinality

Returns:

  • (String)


1612
1613
1614
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1612

def cardinality
  @cardinality
end

#default_valueString

The string value of the default value of this field. Proto2 syntax only. Corresponds to the JSON property defaultValue

Returns:

  • (String)


1617
1618
1619
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1617

def default_value
  @default_value
end

#json_nameString

The field JSON name. Corresponds to the JSON property jsonName

Returns:

  • (String)


1622
1623
1624
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1622

def json_name
  @json_name
end

#kindString

The field type. Corresponds to the JSON property kind

Returns:

  • (String)


1627
1628
1629
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1627

def kind
  @kind
end

#nameString

The field name. Corresponds to the JSON property name

Returns:

  • (String)


1632
1633
1634
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1632

def name
  @name
end

#numberFixnum

The field number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


1637
1638
1639
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1637

def number
  @number
end

#oneof_indexFixnum

The index of the field type in Type.oneofs, for message or enumeration types. The first type has index 1; zero means the type is not in the list. Corresponds to the JSON property oneofIndex

Returns:

  • (Fixnum)


1643
1644
1645
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1643

def oneof_index
  @oneof_index
end

#optionsArray<Google::Apis::ServiceconsumermanagementV1::Option>

The protocol buffer options. Corresponds to the JSON property options



1648
1649
1650
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1648

def options
  @options
end

#packedBoolean Also known as: packed?

Whether to use alternative packed wire representation. Corresponds to the JSON property packed

Returns:

  • (Boolean)


1653
1654
1655
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1653

def packed
  @packed
end

#type_urlString

The field type URL, without the scheme, for message or enumeration types. Example: "type.googleapis.com/google.protobuf.Timestamp". Corresponds to the JSON property typeUrl

Returns:

  • (String)


1660
1661
1662
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1660

def type_url
  @type_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1667

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @default_value = args[:default_value] if args.key?(:default_value)
  @json_name = args[:json_name] if args.key?(:json_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @oneof_index = args[:oneof_index] if args.key?(:oneof_index)
  @options = args[:options] if args.key?(:options)
  @packed = args[:packed] if args.key?(:packed)
  @type_url = args[:type_url] if args.key?(:type_url)
end