Class: Google::Apis::ServiceconsumermanagementV1::MethodPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Defines policies applying to an RPC method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodPolicy

Returns a new instance of MethodPolicy.



2409
2410
2411
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_policiesArray<Google::Apis::ServiceconsumermanagementV1::FieldPolicy>

Policies that are applicable to the request message. Corresponds to the JSON property requestPolicies



2399
2400
2401
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2399

def request_policies
  @request_policies
end

#selectorString

Selects a method to which these policies should be enforced, for example, " google.pubsub.v1.Subscriber.CreateSubscription". Refer to selector for syntax details. NOTE: This field must not be set in the proto annotation. It will be automatically filled by the service config compiler . Corresponds to the JSON property selector

Returns:

  • (String)


2407
2408
2409
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2407

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2414
2415
2416
2417
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2414

def update!(**args)
  @request_policies = args[:request_policies] if args.key?(:request_policies)
  @selector = args[:selector] if args.key?(:selector)
end