Class: Google::Apis::ServiceconsumermanagementV1::MonitoringDestination
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::MonitoringDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
Configuration of a specific monitoring destination (the producer project or the consumer project).
Instance Attribute Summary collapse
-
#metrics ⇒ Array<String>
Types of the metrics to report to this monitoring destination.
-
#monitored_resource ⇒ String
The monitored resource type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MonitoringDestination
constructor
A new instance of MonitoringDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MonitoringDestination
Returns a new instance of MonitoringDestination.
2881 2882 2883 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2881 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metrics ⇒ Array<String>
Types of the metrics to report to this monitoring destination. Each type must
be defined in Service.metrics section.
Corresponds to the JSON property metrics
2873 2874 2875 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2873 def metrics @metrics end |
#monitored_resource ⇒ String
The monitored resource type. The type must be defined in Service.
monitored_resources section.
Corresponds to the JSON property monitoredResource
2879 2880 2881 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2879 def monitored_resource @monitored_resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2886 2887 2888 2889 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2886 def update!(**args) @metrics = args[:metrics] if args.key?(:metrics) @monitored_resource = args[:monitored_resource] if args.key?(:monitored_resource) end |