Class: Google::Apis::ServiceconsumermanagementV1::ServiceConsumerManagementService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ServiceconsumermanagementV1::ServiceConsumerManagementService
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/service.rb
Overview
Service Consumer Management API
Manages the service consumers of a Service Infrastructure service.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://serviceconsumermanagement.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#add_service_tenancy_unit_project(parent, add_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Add a new tenant project to the tenancy unit.
-
#apply_service_tenancy_unit_project_config(name, apply_tenant_project_config_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Apply a configuration to an existing tenant project.
-
#attach_service_tenancy_unit_project(name, attach_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Attach an existing project to the tenancy unit as a new tenant resource.
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_tenancy_unit(parent, create_tenancy_unit_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::TenancyUnit
Creates a tenancy unit with no tenant resources.
-
#delete_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Empty
Deletes a long-running operation.
-
#delete_service_tenancy_unit(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Delete a tenancy unit.
-
#delete_service_tenancy_unit_project(name, delete_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Deletes the specified project resource identified by a tenant resource tag.
-
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ ServiceConsumerManagementService
constructor
A new instance of ServiceConsumerManagementService.
-
#list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_service_tenancy_units(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::ListTenancyUnitsResponse
Find the tenancy unit for a managed service and service consumer.
-
#remove_service_tenancy_unit_project(name, remove_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Removes the specified project resource identified by a tenant resource tag.
-
#search_services(parent, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::SearchTenancyUnitsResponse
Search tenancy units for a managed service.
-
#undelete_service_tenancy_unit_project(name, undelete_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Attempts to undelete a previously deleted tenant project.
Constructor Details
#initialize ⇒ ServiceConsumerManagementService
Returns a new instance of ServiceConsumerManagementService.
47 48 49 50 51 52 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-serviceconsumermanagement_v1', client_version: Google::Apis::ServiceconsumermanagementV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#add_service_tenancy_unit_project(parent, add_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Add a new tenant project to the tenancy unit. There can be a maximum of 1024
tenant projects in a tenancy unit. If there are previously failed
AddTenantProject calls, you might need to call RemoveTenantProject first to
resolve them before you can make another call to AddTenantProject with the
same tag. Operation.
287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 287 def add_service_tenancy_unit_project(parent, add_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:addProject', ) command.request_representation = Google::Apis::ServiceconsumermanagementV1::AddTenantProjectRequest::Representation command.request_object = add_tenant_project_request_object command.response_representation = Google::Apis::ServiceconsumermanagementV1::Operation::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::Operation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#apply_service_tenancy_unit_project_config(name, apply_tenant_project_config_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Apply a configuration to an existing tenant project. This project must exist in an active state and have the original owner account. The caller must have permission to add a project to the given tenancy unit. The configuration is applied, but any existing settings on the project aren't modified. Specified policy bindings are applied. Existing bindings aren't modified. Specified services are activated. No service is deactivated. If specified, new billing configuration is applied. Omit a billing configuration to keep the existing one. A service account in the project is created if previously non existed. Specified labels will be appended to tenant project, note that the value of existing label key will be updated if the same label key is requested. The specified folder is ignored, as moving a tenant project to a different folder isn't supported. The operation fails if any of the steps fail, but no rollback of already applied configuration changes is attempted. Operation.
333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 333 def apply_service_tenancy_unit_project_config(name, apply_tenant_project_config_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:applyProjectConfig', ) command.request_representation = Google::Apis::ServiceconsumermanagementV1::ApplyTenantProjectConfigRequest::Representation command.request_object = apply_tenant_project_config_request_object command.response_representation = Google::Apis::ServiceconsumermanagementV1::Operation::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#attach_service_tenancy_unit_project(name, attach_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Attach an existing project to the tenancy unit as a new tenant resource. The
project could either be the tenant project reserved by calling
AddTenantProject under a tenancy unit of a service producer's project of a
managed service, or from a separate project. The caller is checked against a
set of permissions as if calling AddTenantProject on the same service
consumer. To trigger the attachment, the targeted tenant project must be in a
folder. Make sure the ServiceConsumerManagement service account is the owner
of that project. These two requirements are already met if the project is
reserved by calling AddTenantProject. Operation.
375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 375 def attach_service_tenancy_unit_project(name, attach_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:attachProject', ) command.request_representation = Google::Apis::ServiceconsumermanagementV1::AttachTenantProjectRequest::Representation command.request_object = attach_tenant_project_request_object command.response_representation = Google::Apis::ServiceconsumermanagementV1::Operation::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 82 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::ServiceconsumermanagementV1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::ServiceconsumermanagementV1::Empty::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_tenancy_unit(parent, create_tenancy_unit_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::TenancyUnit
Creates a tenancy unit with no tenant resources. If tenancy unit already exists, it will be returned, however, in this case, returned TenancyUnit does not have tenant_resources field set and ListTenancyUnits has to be used to get a complete TenancyUnit with all fields populated.
416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 416 def create_tenancy_unit(parent, create_tenancy_unit_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/tenancyUnits', ) command.request_representation = Google::Apis::ServiceconsumermanagementV1::CreateTenancyUnitRequest::Representation command.request_object = create_tenancy_unit_request_object command.response_representation = Google::Apis::ServiceconsumermanagementV1::TenancyUnit::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::TenancyUnit command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
117 118 119 120 121 122 123 124 125 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 117 def delete_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ServiceconsumermanagementV1::Empty::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_service_tenancy_unit(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Delete a tenancy unit. Before you delete the tenancy unit, there should be no tenant resources in it that aren't in a DELETED state. Operation.
449 450 451 452 453 454 455 456 457 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 449 def delete_service_tenancy_unit(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::ServiceconsumermanagementV1::Operation::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_service_tenancy_unit_project(name, delete_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Deletes the specified project resource identified by a tenant resource tag.
The mothod removes a project lien with a 'TenantManager' origin if that was
added. It will then attempt to delete the project. If that operation fails,
this method also fails. After the project has been deleted, the tenant
resource state is set to DELETED. To permanently remove resource metadata,
call the RemoveTenantProject method. New resources with the same tag can't
be added if there are existing resources in a DELETED state. Operation.
487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 487 def delete_service_tenancy_unit_project(name, delete_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:deleteProject', ) command.request_representation = Google::Apis::ServiceconsumermanagementV1::DeleteTenantProjectRequest::Representation command.request_object = delete_tenant_project_request_object command.response_representation = Google::Apis::ServiceconsumermanagementV1::Operation::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
148 149 150 151 152 153 154 155 156 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 148 def get_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ServiceconsumermanagementV1::Operation::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 193 def list_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ServiceconsumermanagementV1::ListOperationsResponse::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_service_tenancy_units(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::ListTenancyUnitsResponse
Find the tenancy unit for a managed service and service consumer. This method shouldn't be used in a service producer's runtime path, for example to find the tenant project number when creating VMs. Service producers must persist the tenant project's information after the project is created.
535 536 537 538 539 540 541 542 543 544 545 546 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 535 def list_service_tenancy_units(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/tenancyUnits', ) command.response_representation = Google::Apis::ServiceconsumermanagementV1::ListTenancyUnitsResponse::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::ListTenancyUnitsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#remove_service_tenancy_unit_project(name, remove_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Removes the specified project resource identified by a tenant resource tag. The method removes the project lien with 'TenantManager' origin if that was added. It then attempts to delete the project. If that operation fails, this method also fails. Calls to remove already removed or non-existent tenant project succeed. After the project has been deleted, or if was already in a DELETED state, resource metadata is permanently removed from the tenancy unit. Operation.
576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 576 def remove_service_tenancy_unit_project(name, remove_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:removeProject', ) command.request_representation = Google::Apis::ServiceconsumermanagementV1::RemoveTenantProjectRequest::Representation command.request_object = remove_tenant_project_request_object command.response_representation = Google::Apis::ServiceconsumermanagementV1::Operation::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_services(parent, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::SearchTenancyUnitsResponse
Search tenancy units for a managed service.
248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 248 def search_services(parent, page_size: nil, page_token: nil, query: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}:search', ) command.response_representation = Google::Apis::ServiceconsumermanagementV1::SearchTenancyUnitsResponse::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::SearchTenancyUnitsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['query'] = query unless query.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#undelete_service_tenancy_unit_project(name, undelete_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServiceconsumermanagementV1::Operation
Attempts to undelete a previously deleted tenant project. The project must be
in a DELETED state. There are no guarantees that an undeleted project will be
in a fully restored and functional state. Call the ApplyTenantProjectConfig
method to update its configuration and then validate all managed service
resources. Operation.
614 615 616 617 618 619 620 621 622 623 624 |
# File 'lib/google/apis/serviceconsumermanagement_v1/service.rb', line 614 def undelete_service_tenancy_unit_project(name, undelete_tenant_project_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:undeleteProject', ) command.request_representation = Google::Apis::ServiceconsumermanagementV1::UndeleteTenantProjectRequest::Representation command.request_object = undelete_tenant_project_request_object command.response_representation = Google::Apis::ServiceconsumermanagementV1::Operation::Representation command.response_class = Google::Apis::ServiceconsumermanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |