Class: Google::Apis::ServiceconsumermanagementV1::TenancyUnit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Representation of a tenancy unit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TenancyUnit

Returns a new instance of TenancyUnit.



4084
4085
4086
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4084

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumerString

Output only. @OutputOnly Cloud resource name of the consumer of this service. For example 'projects/123456'. Corresponds to the JSON property consumer

Returns:

  • (String)


4059
4060
4061
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4059

def consumer
  @consumer
end

#create_timeString

Output only. @OutputOnly The time this tenancy unit was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4064
4065
4066
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4064

def create_time
  @create_time
end

#nameString

Globally unique identifier of this tenancy unit "services/service/ collection id/resource id/tenancyUnits/unit" Corresponds to the JSON property name

Returns:

  • (String)


4070
4071
4072
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4070

def name
  @name
end

#serviceString

Output only. Google Cloud API name of the managed service owning this tenancy unit. For example 'serviceconsumermanagement.googleapis.com'. Corresponds to the JSON property service

Returns:

  • (String)


4076
4077
4078
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4076

def service
  @service
end

#tenant_resourcesArray<Google::Apis::ServiceconsumermanagementV1::TenantResource>

Resources constituting the tenancy unit. There can be at most 512 tenant resources in a tenancy unit. Corresponds to the JSON property tenantResources



4082
4083
4084
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4082

def tenant_resources
  @tenant_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4089
4090
4091
4092
4093
4094
4095
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4089

def update!(**args)
  @consumer = args[:consumer] if args.key?(:consumer)
  @create_time = args[:create_time] if args.key?(:create_time)
  @name = args[:name] if args.key?(:name)
  @service = args[:service] if args.key?(:service)
  @tenant_resources = args[:tenant_resources] if args.key?(:tenant_resources)
end