Class: Google::Apis::ServiceconsumermanagementV1::TenantProjectPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Describes policy settings that can be applied to a newly created tenant project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TenantProjectPolicy

Returns a new instance of TenantProjectPolicy.



4195
4196
4197
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4195

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policy_bindingsArray<Google::Apis::ServiceconsumermanagementV1::PolicyBinding>

Policy bindings to be applied to the tenant project, in addition to the 'roles/ owner' role granted to the Service Consumer Management service account. Corresponds to the JSON property policyBindings



4193
4194
4195
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4193

def policy_bindings
  @policy_bindings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4200
4201
4202
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4200

def update!(**args)
  @policy_bindings = args[:policy_bindings] if args.key?(:policy_bindings)
end