Class: Google::Apis::ServiceconsumermanagementV1::V1AddVisibilityLabelsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Response message for the AddVisibilityLabels method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1AddVisibilityLabelsResponse

Returns a new instance of V1AddVisibilityLabelsResponse.



4430
4431
4432
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4430

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsArray<String>

The updated set of visibility labels for this consumer on this service. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


4428
4429
4430
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4428

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4435
4436
4437
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4435

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
end