Class: Google::Apis::ServiceconsumermanagementV1::V1Beta1GenerateServiceIdentityResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Response message for the GenerateServiceIdentity method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1Beta1GenerateServiceIdentityResponse

Returns a new instance of V1Beta1GenerateServiceIdentityResponse.



4472
4473
4474
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4472

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#identityGoogle::Apis::ServiceconsumermanagementV1::V1Beta1ServiceIdentity

A service identity in the Identity and Access Management API. Corresponds to the JSON property identity



4470
4471
4472
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4470

def identity
  @identity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4477
4478
4479
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4477

def update!(**args)
  @identity = args[:identity] if args.key?(:identity)
end