Class: Google::Apis::ServiceconsumermanagementV1::V1Beta1QuotaOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

A quota override

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1Beta1QuotaOverride

Returns a new instance of V1Beta1QuotaOverride.



4637
4638
4639
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4637

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_override_ancestorString

The resource name of the ancestor that requested the override. For example: " organizations/12345" or "folders/67890". Used by admin overrides only. Corresponds to the JSON property adminOverrideAncestor

Returns:

  • (String)


4590
4591
4592
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4590

def admin_override_ancestor
  @admin_override_ancestor
end

#dimensionsHash<String,String>

If this map is nonempty, then this override applies only to specific values for dimensions defined in the limit unit. For example, an override on a limit with the unit 1/project/region could contain an entry with the key "region" and the value "us-east-1"; the override is only applied to quota consumed in that region. This map has the following restrictions: * Keys that are not defined in the limit's unit are not valid keys. Any string appearing in brackets in the unit (besides project or user) is a defined key. * " project" is not a valid key; the project is already specified in the parent resource name. * "user" is not a valid key; the API does not support quota overrides that apply only to a specific user. * If "region" appears as a key, its value must be a valid Cloud region. * If "zone" appears as a key, its value must be a valid Cloud zone. * If any valid key other than "region" or " zone" appears in the map, then all valid keys other than "region" or "zone" must also appear in the map. Corresponds to the JSON property dimensions

Returns:

  • (Hash<String,String>)


4608
4609
4610
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4608

def dimensions
  @dimensions
end

#metricString

The name of the metric to which this override applies. An example name would be: compute.googleapis.com/cpus Corresponds to the JSON property metric

Returns:

  • (String)


4614
4615
4616
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4614

def metric
  @metric
end

#nameString

The resource name of the producer override. An example name would be: services/compute.googleapis.com/projects/123/consumerQuotaMetrics/compute. googleapis.com%2Fcpus/limits/%2Fproject%2Fregion/producerOverrides/4a3f2c1d Corresponds to the JSON property name

Returns:

  • (String)


4621
4622
4623
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4621

def name
  @name
end

#override_valueFixnum

The overriding quota limit value. Can be any nonnegative integer, or -1 ( unlimited quota). Corresponds to the JSON property overrideValue

Returns:

  • (Fixnum)


4627
4628
4629
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4627

def override_value
  @override_value
end

#unitString

The limit unit of the limit to which this override applies. An example unit would be: 1/project/regionNote thatprojectandregionare not placeholders in this example; the literal charactersand`occur in the string. Corresponds to the JSON propertyunit`

Returns:

  • (String)


4635
4636
4637
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4635

def unit
  @unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4642
4643
4644
4645
4646
4647
4648
4649
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4642

def update!(**args)
  @admin_override_ancestor = args[:admin_override_ancestor] if args.key?(:admin_override_ancestor)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @metric = args[:metric] if args.key?(:metric)
  @name = args[:name] if args.key?(:name)
  @override_value = args[:override_value] if args.key?(:override_value)
  @unit = args[:unit] if args.key?(:unit)
end