Class: Google::Apis::ServiceconsumermanagementV1::V1EnableConsumerResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Response message for the EnableConsumer method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1EnableConsumerResponse

Returns a new instance of V1EnableConsumerResponse.



4818
4819
4820
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4818

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4823
4824
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4823

def update!(**args)
end