Class: Google::Apis::ServiceconsumermanagementV1::V1RemoveVisibilityLabelsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Response message for the RemoveVisibilityLabels method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1RemoveVisibilityLabelsResponse

Returns a new instance of V1RemoveVisibilityLabelsResponse.



4872
4873
4874
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4872

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsArray<String>

The updated set of visibility labels for this consumer on this service. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


4870
4871
4872
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4870

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4877
4878
4879
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4877

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
end