Class: Google::Apis::ServiceconsumermanagementV1::V1ServiceAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

A service account in the Identity and Access Management API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1ServiceAccount

Returns a new instance of V1ServiceAccount.



4913
4914
4915
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4913

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emailString

The email address of the service account. Corresponds to the JSON property email

Returns:

  • (String)


4889
4890
4891
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4889

def email
  @email
end

#iam_account_nameString

Deprecated. See b/136209818. Corresponds to the JSON property iamAccountName

Returns:

  • (String)


4894
4895
4896
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4894

def 
  @iam_account_name
end

#nameString

P4 SA resource name. An example name would be: services/ serviceconsumermanagement.googleapis.com/projects/123/serviceAccounts/default Corresponds to the JSON property name

Returns:

  • (String)


4900
4901
4902
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4900

def name
  @name
end

#tagString

The P4 SA configuration tag. This must be defined in activation_grants. If not specified when creating the account, the tag is set to "default". Corresponds to the JSON property tag

Returns:

  • (String)


4906
4907
4908
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4906

def tag
  @tag
end

#unique_idString

The unique and stable id of the service account. Corresponds to the JSON property uniqueId

Returns:

  • (String)


4911
4912
4913
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4911

def unique_id
  @unique_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4918
4919
4920
4921
4922
4923
4924
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4918

def update!(**args)
  @email = args[:email] if args.key?(:email)
  @iam_account_name = args[:iam_account_name] if args.key?(:iam_account_name)
  @name = args[:name] if args.key?(:name)
  @tag = args[:tag] if args.key?(:tag)
  @unique_id = args[:unique_id] if args.key?(:unique_id)
end