Class: Google::Apis::ServiceconsumermanagementV1::ApplyTenantProjectConfigRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::ApplyTenantProjectConfigRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
Request to apply configuration to an existing tenant project.
Instance Attribute Summary collapse
-
#project_config ⇒ Google::Apis::ServiceconsumermanagementV1::TenantProjectConfig
This structure defines a tenant project to be added to the specified tenancy unit and its initial configuration and properties.
-
#tag ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApplyTenantProjectConfigRequest
constructor
A new instance of ApplyTenantProjectConfigRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApplyTenantProjectConfigRequest
Returns a new instance of ApplyTenantProjectConfigRequest.
155 156 157 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 155 def initialize(**args) update!(**args) end |
Instance Attribute Details
#project_config ⇒ Google::Apis::ServiceconsumermanagementV1::TenantProjectConfig
This structure defines a tenant project to be added to the specified tenancy
unit and its initial configuration and properties. A project lien is created
for the tenant project to prevent the tenant project from being deleted
accidentally. The lien is deleted as part of tenant project removal.
Corresponds to the JSON property projectConfig
148 149 150 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 148 def project_config @project_config end |
#tag ⇒ String
Required. Tag of the project. Must be less than 128 characters. Required.
Corresponds to the JSON property tag
153 154 155 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 153 def tag @tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
160 161 162 163 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 160 def update!(**args) @project_config = args[:project_config] if args.key?(:project_config) @tag = args[:tag] if args.key?(:tag) end |