Class: Google::Apis::ServiceconsumermanagementV1::AttachTenantProjectRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::AttachTenantProjectRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
Request to attach an existing project to the tenancy unit as a new tenant resource.
Instance Attribute Summary collapse
-
#external_resource ⇒ String
When attaching an external project, this is in the format of
projects/project_number``. -
#reserved_resource ⇒ String
When attaching a reserved project already in tenancy units, this is the tag of a tenant resource under the tenancy unit for the managed service's service producer project.
-
#tag ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AttachTenantProjectRequest
constructor
A new instance of AttachTenantProjectRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AttachTenantProjectRequest
Returns a new instance of AttachTenantProjectRequest.
250 251 252 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 250 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_resource ⇒ String
When attaching an external project, this is in the format of projects/
project_number`.
Corresponds to the JSON propertyexternalResource`
235 236 237 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 235 def external_resource @external_resource end |
#reserved_resource ⇒ String
When attaching a reserved project already in tenancy units, this is the tag of
a tenant resource under the tenancy unit for the managed service's service
producer project. The reserved tenant resource must be in an active state.
Corresponds to the JSON property reservedResource
242 243 244 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 242 def reserved_resource @reserved_resource end |
#tag ⇒ String
Required. Tag of the tenant resource after attachment. Must be less than 128
characters. Required.
Corresponds to the JSON property tag
248 249 250 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 248 def tag @tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
255 256 257 258 259 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 255 def update!(**args) @external_resource = args[:external_resource] if args.key?(:external_resource) @reserved_resource = args[:reserved_resource] if args.key?(:reserved_resource) @tag = args[:tag] if args.key?(:tag) end |