Class: Google::Apis::ServiceconsumermanagementV1::ClientLibrarySettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Details about how and where to publish client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClientLibrarySettings

Returns a new instance of ClientLibrarySettings.



881
882
883
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 881

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpp_settingsGoogle::Apis::ServiceconsumermanagementV1::CppSettings

Settings for C++ client libraries. Corresponds to the JSON property cppSettings



825
826
827
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 825

def cpp_settings
  @cpp_settings
end

#dotnet_settingsGoogle::Apis::ServiceconsumermanagementV1::DotnetSettings

Settings for Dotnet client libraries. Corresponds to the JSON property dotnetSettings



830
831
832
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 830

def dotnet_settings
  @dotnet_settings
end

#go_settingsGoogle::Apis::ServiceconsumermanagementV1::GoSettings

Settings for Go client libraries. Corresponds to the JSON property goSettings



835
836
837
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 835

def go_settings
  @go_settings
end

#java_settingsGoogle::Apis::ServiceconsumermanagementV1::JavaSettings

Settings for Java client libraries. Corresponds to the JSON property javaSettings



840
841
842
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 840

def java_settings
  @java_settings
end

#launch_stageString

Launch stage of this version of the API. Corresponds to the JSON property launchStage

Returns:

  • (String)


845
846
847
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 845

def launch_stage
  @launch_stage
end

#node_settingsGoogle::Apis::ServiceconsumermanagementV1::NodeSettings

Settings for Node client libraries. Corresponds to the JSON property nodeSettings



850
851
852
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 850

def node_settings
  @node_settings
end

#php_settingsGoogle::Apis::ServiceconsumermanagementV1::PhpSettings

Settings for Php client libraries. Corresponds to the JSON property phpSettings



855
856
857
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 855

def php_settings
  @php_settings
end

#python_settingsGoogle::Apis::ServiceconsumermanagementV1::PythonSettings

Settings for Python client libraries. Corresponds to the JSON property pythonSettings



860
861
862
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 860

def python_settings
  @python_settings
end

#rest_numeric_enumsBoolean Also known as: rest_numeric_enums?

When using transport=rest, the client request will encode enums as numbers rather than strings. Corresponds to the JSON property restNumericEnums

Returns:

  • (Boolean)


866
867
868
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 866

def rest_numeric_enums
  @rest_numeric_enums
end

#ruby_settingsGoogle::Apis::ServiceconsumermanagementV1::RubySettings

Settings for Ruby client libraries. Corresponds to the JSON property rubySettings



872
873
874
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 872

def ruby_settings
  @ruby_settings
end

#versionString

Version of the API to apply these settings to. This is the full protobuf package for the API, ending in the version element. Examples: "google.cloud. speech.v1" and "google.spanner.admin.database.v1". Corresponds to the JSON property version

Returns:

  • (String)


879
880
881
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 879

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



886
887
888
889
890
891
892
893
894
895
896
897
898
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 886

def update!(**args)
  @cpp_settings = args[:cpp_settings] if args.key?(:cpp_settings)
  @dotnet_settings = args[:dotnet_settings] if args.key?(:dotnet_settings)
  @go_settings = args[:go_settings] if args.key?(:go_settings)
  @java_settings = args[:java_settings] if args.key?(:java_settings)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @node_settings = args[:node_settings] if args.key?(:node_settings)
  @php_settings = args[:php_settings] if args.key?(:php_settings)
  @python_settings = args[:python_settings] if args.key?(:python_settings)
  @rest_numeric_enums = args[:rest_numeric_enums] if args.key?(:rest_numeric_enums)
  @ruby_settings = args[:ruby_settings] if args.key?(:ruby_settings)
  @version = args[:version] if args.key?(:version)
end