Class: Google::Apis::ServiceconsumermanagementV1::Enum
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::Enum
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
Enum type definition. New usages of this message as an alternative to EnumDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#enumvalue ⇒ Array<Google::Apis::ServiceconsumermanagementV1::EnumValue>
Enum value definitions.
-
#name ⇒ String
Enum type name.
-
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1::Option>
Protocol buffer options.
-
#source_context ⇒ Google::Apis::ServiceconsumermanagementV1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Enum
constructor
A new instance of Enum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Enum
Returns a new instance of Enum.
1508 1509 1510 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1508 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
1480 1481 1482 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1480 def edition @edition end |
#enumvalue ⇒ Array<Google::Apis::ServiceconsumermanagementV1::EnumValue>
Enum value definitions.
Corresponds to the JSON property enumvalue
1485 1486 1487 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1485 def enumvalue @enumvalue end |
#name ⇒ String
Enum type name.
Corresponds to the JSON property name
1490 1491 1492 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1490 def name @name end |
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1::Option>
Protocol buffer options.
Corresponds to the JSON property options
1495 1496 1497 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1495 def @options end |
#source_context ⇒ Google::Apis::ServiceconsumermanagementV1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
1501 1502 1503 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1501 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
1506 1507 1508 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1506 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1513 1514 1515 1516 1517 1518 1519 1520 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1513 def update!(**args) @edition = args[:edition] if args.key?(:edition) @enumvalue = args[:enumvalue] if args.key?(:enumvalue) @name = args[:name] if args.key?(:name) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |