Class: Google::Apis::ServiceconsumermanagementV1::Enum
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::Enum
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
Enum type definition. New usages of this message as an alternative to EnumDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#enumvalue ⇒ Array<Google::Apis::ServiceconsumermanagementV1::EnumValue>
Enum value definitions.
-
#name ⇒ String
Enum type name.
-
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1::Option>
Protocol buffer options.
-
#source_context ⇒ Google::Apis::ServiceconsumermanagementV1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Enum
constructor
A new instance of Enum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Enum
Returns a new instance of Enum.
1505 1506 1507 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1505 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
1477 1478 1479 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1477 def edition @edition end |
#enumvalue ⇒ Array<Google::Apis::ServiceconsumermanagementV1::EnumValue>
Enum value definitions.
Corresponds to the JSON property enumvalue
1482 1483 1484 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1482 def enumvalue @enumvalue end |
#name ⇒ String
Enum type name.
Corresponds to the JSON property name
1487 1488 1489 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1487 def name @name end |
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1::Option>
Protocol buffer options.
Corresponds to the JSON property options
1492 1493 1494 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1492 def @options end |
#source_context ⇒ Google::Apis::ServiceconsumermanagementV1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
1498 1499 1500 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1498 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
1503 1504 1505 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1503 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1510 1511 1512 1513 1514 1515 1516 1517 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 1510 def update!(**args) @edition = args[:edition] if args.key?(:edition) @enumvalue = args[:enumvalue] if args.key?(:enumvalue) @name = args[:name] if args.key?(:name) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |