Class: Google::Apis::ServiceconsumermanagementV1::MethodProp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Method represents a method of an API interface. New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodProp

Returns a new instance of MethodProp.



2375
2376
2377
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. This field should be ignored, instead the edition should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property edition

Returns:

  • (String)


2335
2336
2337
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2335

def edition
  @edition
end

#nameString

The simple name of this method. Corresponds to the JSON property name

Returns:

  • (String)


2340
2341
2342
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2340

def name
  @name
end

#optionsArray<Google::Apis::ServiceconsumermanagementV1::Option>

Any metadata attached to the method. Corresponds to the JSON property options



2345
2346
2347
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2345

def options
  @options
end

#request_streamingBoolean Also known as: request_streaming?

If true, the request is streamed. Corresponds to the JSON property requestStreaming

Returns:

  • (Boolean)


2350
2351
2352
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2350

def request_streaming
  @request_streaming
end

#request_type_urlString

A URL of the input message type. Corresponds to the JSON property requestTypeUrl

Returns:

  • (String)


2356
2357
2358
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2356

def request_type_url
  @request_type_url
end

#response_streamingBoolean Also known as: response_streaming?

If true, the response is streamed. Corresponds to the JSON property responseStreaming

Returns:

  • (Boolean)


2361
2362
2363
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2361

def response_streaming
  @response_streaming
end

#response_type_urlString

The URL of the output message type. Corresponds to the JSON property responseTypeUrl

Returns:

  • (String)


2367
2368
2369
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2367

def response_type_url
  @response_type_url
end

#syntaxString

The source syntax of this method. This field should be ignored, instead the syntax should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property syntax

Returns:

  • (String)


2373
2374
2375
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2373

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2380

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @request_streaming = args[:request_streaming] if args.key?(:request_streaming)
  @request_type_url = args[:request_type_url] if args.key?(:request_type_url)
  @response_streaming = args[:response_streaming] if args.key?(:response_streaming)
  @response_type_url = args[:response_type_url] if args.key?(:response_type_url)
  @syntax = args[:syntax] if args.key?(:syntax)
end