Class: Google::Apis::ServiceconsumermanagementV1::MetricDescriptorMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Additional annotations that can be used to guide the usage of a metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricDescriptorMetadata

Returns a new instance of MetricDescriptorMetadata.



2640
2641
2642
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ingest_delayString

The delay of data points caused by ingestion. Data points older than this age are guaranteed to be ingested and available to be read, excluding data loss due to errors. Corresponds to the JSON property ingestDelay

Returns:

  • (String)


2620
2621
2622
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2620

def ingest_delay
  @ingest_delay
end

#launch_stageString

Deprecated. Must use the MetricDescriptor.launch_stage instead. Corresponds to the JSON property launchStage

Returns:

  • (String)


2625
2626
2627
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2625

def launch_stage
  @launch_stage
end

#sample_periodString

The sampling period of metric data points. For metrics which are written periodically, consecutive data points are stored at this time interval, excluding data loss due to errors. Metrics with a higher granularity have a smaller sampling period. Corresponds to the JSON property samplePeriod

Returns:

  • (String)


2633
2634
2635
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2633

def sample_period
  @sample_period
end

#time_series_resource_hierarchy_levelArray<String>

The scope of the timeseries data of the metric. Corresponds to the JSON property timeSeriesResourceHierarchyLevel

Returns:

  • (Array<String>)


2638
2639
2640
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2638

def time_series_resource_hierarchy_level
  @time_series_resource_hierarchy_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2645
2646
2647
2648
2649
2650
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2645

def update!(**args)
  @ingest_delay = args[:ingest_delay] if args.key?(:ingest_delay)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @sample_period = args[:sample_period] if args.key?(:sample_period)
  @time_series_resource_hierarchy_level = args[:time_series_resource_hierarchy_level] if args.key?(:time_series_resource_hierarchy_level)
end