Class: Google::Apis::ServiceconsumermanagementV1::MetricRule
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::MetricRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
Bind API methods to metrics. Binding a method to a metric causes that metric's configured quota behaviors to apply to the method call.
Instance Attribute Summary collapse
-
#agentic_metric_costs ⇒ Hash<String,Fixnum>
Optional.
-
#metric_costs ⇒ Hash<String,Fixnum>
Metrics to update when the selected methods are called, and the associated cost applied to each metric.
-
#nonagentic_metric_costs ⇒ Hash<String,Fixnum>
Optional.
-
#selector ⇒ String
Selects the methods to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricRule
constructor
A new instance of MetricRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricRule
Returns a new instance of MetricRule.
2693 2694 2695 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agentic_metric_costs ⇒ Hash<String,Fixnum>
Optional. Metrics to update when the selected methods are called, and the
associated cost applied to each metric, iff the source of the call is an agent.
The key of the map is the metric name, and the values are the amount
increased for the metric against which the quota limits are defined. The value
must not be negative.
Corresponds to the JSON property agenticMetricCosts
2668 2669 2670 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2668 def agentic_metric_costs @agentic_metric_costs end |
#metric_costs ⇒ Hash<String,Fixnum>
Metrics to update when the selected methods are called, and the associated
cost applied to each metric. The key of the map is the metric name, and the
values are the amount increased for the metric against which the quota limits
are defined. The value must not be negative.
Corresponds to the JSON property metricCosts
2676 2677 2678 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2676 def metric_costs @metric_costs end |
#nonagentic_metric_costs ⇒ Hash<String,Fixnum>
Optional. Metrics to update when the selected methods are called, and the
associated cost applied to each metric, iff the source of the call is not an
agent. The key of the map is the metric name, and the values are the amount
increased for the metric against which the quota limits are defined. The value
must not be negative.
Corresponds to the JSON property nonagenticMetricCosts
2685 2686 2687 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2685 def nonagentic_metric_costs @nonagentic_metric_costs end |
#selector ⇒ String
Selects the methods to which this rule applies. Refer to selector for syntax
details.
Corresponds to the JSON property selector
2691 2692 2693 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2691 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2698 2699 2700 2701 2702 2703 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 2698 def update!(**args) @agentic_metric_costs = args[:agentic_metric_costs] if args.key?(:agentic_metric_costs) @metric_costs = args[:metric_costs] if args.key?(:metric_costs) @nonagentic_metric_costs = args[:nonagentic_metric_costs] if args.key?(:nonagentic_metric_costs) @selector = args[:selector] if args.key?(:selector) end |