Class: Google::Apis::ServiceconsumermanagementV1::Publishing
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::Publishing
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
This message configures the settings for publishing Google Cloud Client libraries generated from the service config.
Instance Attribute Summary collapse
-
#api_short_name ⇒ String
Used as a tracking tag when collecting data about the APIs developer relations artifacts like docs, packages delivered to package managers, etc.
-
#codeowner_github_teams ⇒ Array<String>
GitHub teams to be added to CODEOWNERS in the directory in GitHub containing source code for the client libraries for this API.
-
#doc_tag_prefix ⇒ String
A prefix used in sample code when demarking regions to be included in documentation.
-
#documentation_uri ⇒ String
Link to product home page.
-
#github_label ⇒ String
GitHub label to apply to issues and pull requests opened for this API.
-
#library_settings ⇒ Array<Google::Apis::ServiceconsumermanagementV1::ClientLibrarySettings>
Client library settings.
-
#method_settings ⇒ Array<Google::Apis::ServiceconsumermanagementV1::MethodSettings>
A list of API method settings, e.g.
-
#new_issue_uri ⇒ String
Link to a public URI where users can report issues.
-
#organization ⇒ String
For whom the client library is being published.
-
#proto_reference_documentation_uri ⇒ String
Optional link to proto reference documentation.
-
#rest_reference_documentation_uri ⇒ String
Optional link to REST reference documentation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Publishing
constructor
A new instance of Publishing.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Publishing
Returns a new instance of Publishing.
3209 3210 3211 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3209 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_short_name ⇒ String
Used as a tracking tag when collecting data about the APIs developer relations
artifacts like docs, packages delivered to package managers, etc. Example: "
speech".
Corresponds to the JSON property apiShortName
3148 3149 3150 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3148 def api_short_name @api_short_name end |
#codeowner_github_teams ⇒ Array<String>
GitHub teams to be added to CODEOWNERS in the directory in GitHub containing
source code for the client libraries for this API.
Corresponds to the JSON property codeownerGithubTeams
3154 3155 3156 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3154 def codeowner_github_teams @codeowner_github_teams end |
#doc_tag_prefix ⇒ String
A prefix used in sample code when demarking regions to be included in
documentation.
Corresponds to the JSON property docTagPrefix
3160 3161 3162 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3160 def doc_tag_prefix @doc_tag_prefix end |
#documentation_uri ⇒ String
Link to product home page. Example: https://cloud.google.com/asset-inventory/
docs/overview
Corresponds to the JSON property documentationUri
3166 3167 3168 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3166 def documentation_uri @documentation_uri end |
#github_label ⇒ String
GitHub label to apply to issues and pull requests opened for this API.
Corresponds to the JSON property githubLabel
3171 3172 3173 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3171 def github_label @github_label end |
#library_settings ⇒ Array<Google::Apis::ServiceconsumermanagementV1::ClientLibrarySettings>
Client library settings. If the same version string appears multiple times in
this list, then the last one wins. Settings from earlier settings with the
same version string are discarded.
Corresponds to the JSON property librarySettings
3178 3179 3180 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3178 def library_settings @library_settings end |
#method_settings ⇒ Array<Google::Apis::ServiceconsumermanagementV1::MethodSettings>
A list of API method settings, e.g. the behavior for methods that use the long-
running operation pattern.
Corresponds to the JSON property methodSettings
3184 3185 3186 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3184 def method_settings @method_settings end |
#new_issue_uri ⇒ String
Link to a public URI where users can report issues. Example: https://
issuetracker.google.com/issues/new?component=190865&template=1161103
Corresponds to the JSON property newIssueUri
3190 3191 3192 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3190 def new_issue_uri @new_issue_uri end |
#organization ⇒ String
For whom the client library is being published.
Corresponds to the JSON property organization
3195 3196 3197 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3195 def organization @organization end |
#proto_reference_documentation_uri ⇒ String
Optional link to proto reference documentation. Example: https://cloud.google.
com/pubsub/lite/docs/reference/rpc
Corresponds to the JSON property protoReferenceDocumentationUri
3201 3202 3203 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3201 def proto_reference_documentation_uri @proto_reference_documentation_uri end |
#rest_reference_documentation_uri ⇒ String
Optional link to REST reference documentation. Example: https://cloud.google.
com/pubsub/lite/docs/reference/rest
Corresponds to the JSON property restReferenceDocumentationUri
3207 3208 3209 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3207 def rest_reference_documentation_uri @rest_reference_documentation_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3214 def update!(**args) @api_short_name = args[:api_short_name] if args.key?(:api_short_name) @codeowner_github_teams = args[:codeowner_github_teams] if args.key?(:codeowner_github_teams) @doc_tag_prefix = args[:doc_tag_prefix] if args.key?(:doc_tag_prefix) @documentation_uri = args[:documentation_uri] if args.key?(:documentation_uri) @github_label = args[:github_label] if args.key?(:github_label) @library_settings = args[:library_settings] if args.key?(:library_settings) @method_settings = args[:method_settings] if args.key?(:method_settings) @new_issue_uri = args[:new_issue_uri] if args.key?(:new_issue_uri) @organization = args[:organization] if args.key?(:organization) @proto_reference_documentation_uri = args[:proto_reference_documentation_uri] if args.key?(:proto_reference_documentation_uri) @rest_reference_documentation_uri = args[:rest_reference_documentation_uri] if args.key?(:rest_reference_documentation_uri) end |