Class: Google::Apis::ServiceconsumermanagementV1::PythonSettings
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::PythonSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
Settings for Python client libraries.
Instance Attribute Summary collapse
-
#common ⇒ Google::Apis::ServiceconsumermanagementV1::CommonLanguageSettings
Required information for every language.
-
#experimental_features ⇒ Google::Apis::ServiceconsumermanagementV1::ExperimentalFeatures
Experimental features to be included during client library generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PythonSettings
constructor
A new instance of PythonSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PythonSettings
Returns a new instance of PythonSettings.
3247 3248 3249 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3247 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common ⇒ Google::Apis::ServiceconsumermanagementV1::CommonLanguageSettings
Required information for every language.
Corresponds to the JSON property common
3239 3240 3241 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3239 def common @common end |
#experimental_features ⇒ Google::Apis::ServiceconsumermanagementV1::ExperimentalFeatures
Experimental features to be included during client library generation. These
fields will be deprecated once the feature graduates and is enabled by default.
Corresponds to the JSON property experimentalFeatures
3245 3246 3247 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3245 def experimental_features @experimental_features end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3252 3253 3254 3255 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 3252 def update!(**args) @common = args[:common] if args.key?(:common) @experimental_features = args[:experimental_features] if args.key?(:experimental_features) end |