Class: Google::Apis::ServiceconsumermanagementV1::TenantProjectConfig
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::TenantProjectConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
This structure defines a tenant project to be added to the specified tenancy unit and its initial configuration and properties. A project lien is created for the tenant project to prevent the tenant project from being deleted accidentally. The lien is deleted as part of tenant project removal.
Instance Attribute Summary collapse
-
#billing_config ⇒ Google::Apis::ServiceconsumermanagementV1::BillingConfig
Describes the billing configuration for a new tenant project.
-
#folder ⇒ String
Folder where project in this tenancy unit must be located This folder must have been previously created with the required permissions for the caller to create and configure a project in it.
-
#labels ⇒ Hash<String,String>
Labels that are applied to this project.
-
#service_account_config ⇒ Google::Apis::ServiceconsumermanagementV1::ServiceAccountConfig
Describes the service account configuration for the tenant project.
-
#services ⇒ Array<String>
Google Cloud API names of services that are activated on this project during provisioning.
-
#tenant_project_policy ⇒ Google::Apis::ServiceconsumermanagementV1::TenantProjectPolicy
Describes policy settings that can be applied to a newly created tenant project.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TenantProjectConfig
constructor
A new instance of TenantProjectConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TenantProjectConfig
Returns a new instance of TenantProjectConfig.
4141 4142 4143 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billing_config ⇒ Google::Apis::ServiceconsumermanagementV1::BillingConfig
Describes the billing configuration for a new tenant project.
Corresponds to the JSON property billingConfig
4108 4109 4110 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4108 def billing_config @billing_config end |
#folder ⇒ String
Folder where project in this tenancy unit must be located This folder must
have been previously created with the required permissions for the caller to
create and configure a project in it. Valid folder resource names have the
format folders/folder_number`(for example,folders/123456).
Corresponds to the JSON propertyfolder`
4116 4117 4118 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4116 def folder @folder end |
#labels ⇒ Hash<String,String>
Labels that are applied to this project.
Corresponds to the JSON property labels
4121 4122 4123 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4121 def labels @labels end |
#service_account_config ⇒ Google::Apis::ServiceconsumermanagementV1::ServiceAccountConfig
Describes the service account configuration for the tenant project.
Corresponds to the JSON property serviceAccountConfig
4126 4127 4128 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4126 def service_account_config @service_account_config end |
#services ⇒ Array<String>
Google Cloud API names of services that are activated on this project during
provisioning. If any of these services can't be activated, the request fails.
For example: 'compute.googleapis.com','cloudfunctions.googleapis.com'
Corresponds to the JSON property services
4133 4134 4135 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4133 def services @services end |
#tenant_project_policy ⇒ Google::Apis::ServiceconsumermanagementV1::TenantProjectPolicy
Describes policy settings that can be applied to a newly created tenant
project.
Corresponds to the JSON property tenantProjectPolicy
4139 4140 4141 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4139 def tenant_project_policy @tenant_project_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4146 4147 4148 4149 4150 4151 4152 4153 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4146 def update!(**args) @billing_config = args[:billing_config] if args.key?(:billing_config) @folder = args[:folder] if args.key?(:folder) @labels = args[:labels] if args.key?(:labels) @service_account_config = args[:service_account_config] if args.key?(:service_account_config) @services = args[:services] if args.key?(:services) @tenant_project_policy = args[:tenant_project_policy] if args.key?(:tenant_project_policy) end |