Class: Google::Apis::ServiceconsumermanagementV1::TenantResource
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::TenantResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
Resource constituting the TenancyUnit.
Instance Attribute Summary collapse
-
#migrated_tenant_project ⇒ String
Output only.
-
#resource ⇒ String
Output only.
-
#source_tenant_project ⇒ String
Output only.
-
#status ⇒ String
Status of tenant resource.
-
#tag ⇒ String
Unique per single tenancy unit.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TenantResource
constructor
A new instance of TenantResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TenantResource
Returns a new instance of TenantResource.
4241 4242 4243 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#migrated_tenant_project ⇒ String
Output only. The newly created regional resource name of the tenant project
that has been migrated from a global service. This field is only set for
migrated tenant projects. Format: services//collection_id/RESOURCE_ID/
locations/LOCATION/tenantProjects/TENANT_ID`.
Corresponds to the JSON propertymigratedTenantProject`
4215 4216 4217 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4215 def migrated_tenant_project @migrated_tenant_project end |
#resource ⇒ String
Output only. @OutputOnly Identifier of the tenant resource. For cloud projects,
it is in the form 'projects/number'. For example 'projects/123456'.
Corresponds to the JSON property resource
4221 4222 4223 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4221 def resource @resource end |
#source_tenant_project ⇒ String
Output only. The resource name of the tenant project from which this active
regional tenant project was migrated. This field is only set for active
regional migrated mapping tenant projects. Format: services//collection_id/
RESOURCE_ID/locations/LOCATION/tenantProjects/TENANT_ID`.
Corresponds to the JSON propertysourceTenantProject`
4229 4230 4231 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4229 def source_tenant_project @source_tenant_project end |
#status ⇒ String
Status of tenant resource.
Corresponds to the JSON property status
4234 4235 4236 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4234 def status @status end |
#tag ⇒ String
Unique per single tenancy unit.
Corresponds to the JSON property tag
4239 4240 4241 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4239 def tag @tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4246 4247 4248 4249 4250 4251 4252 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4246 def update!(**args) @migrated_tenant_project = args[:migrated_tenant_project] if args.key?(:migrated_tenant_project) @resource = args[:resource] if args.key?(:resource) @source_tenant_project = args[:source_tenant_project] if args.key?(:source_tenant_project) @status = args[:status] if args.key?(:status) @tag = args[:tag] if args.key?(:tag) end |