Class: Google::Apis::ServiceconsumermanagementV1::TenantResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Resource constituting the TenancyUnit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TenantResource

Returns a new instance of TenantResource.



4207
4208
4209
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4207

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#migrated_tenant_projectString

Output only. The newly created regional resource name of the tenant project that has been migrated from a global service. This field is only set for migrated tenant projects. Format: services//collection_id/RESOURCE_ID/ locations/LOCATION/tenantProjects/TENANT_ID`. Corresponds to the JSON propertymigratedTenantProject`

Returns:

  • (String)


4189
4190
4191
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4189

def migrated_tenant_project
  @migrated_tenant_project
end

#resourceString

Output only. @OutputOnly Identifier of the tenant resource. For cloud projects, it is in the form 'projects/number'. For example 'projects/123456'. Corresponds to the JSON property resource

Returns:

  • (String)


4195
4196
4197
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4195

def resource
  @resource
end

#statusString

Status of tenant resource. Corresponds to the JSON property status

Returns:

  • (String)


4200
4201
4202
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4200

def status
  @status
end

#tagString

Unique per single tenancy unit. Corresponds to the JSON property tag

Returns:

  • (String)


4205
4206
4207
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4205

def tag
  @tag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4212
4213
4214
4215
4216
4217
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4212

def update!(**args)
  @migrated_tenant_project = args[:migrated_tenant_project] if args.key?(:migrated_tenant_project)
  @resource = args[:resource] if args.key?(:resource)
  @status = args[:status] if args.key?(:status)
  @tag = args[:tag] if args.key?(:tag)
end