Class: Google::Apis::ServiceconsumermanagementV1::Type
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::Type
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#fields ⇒ Array<Google::Apis::ServiceconsumermanagementV1::Field>
The list of fields.
-
#name ⇒ String
The fully qualified message name.
-
#oneofs ⇒ Array<String>
The list of types appearing in
oneofdefinitions in this type. -
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1::Option>
The protocol buffer options.
-
#source_context ⇒ Google::Apis::ServiceconsumermanagementV1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Type
constructor
A new instance of Type.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Type
Returns a new instance of Type.
4271 4272 4273 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
4238 4239 4240 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4238 def edition @edition end |
#fields ⇒ Array<Google::Apis::ServiceconsumermanagementV1::Field>
The list of fields.
Corresponds to the JSON property fields
4243 4244 4245 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4243 def fields @fields end |
#name ⇒ String
The fully qualified message name.
Corresponds to the JSON property name
4248 4249 4250 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4248 def name @name end |
#oneofs ⇒ Array<String>
The list of types appearing in oneof definitions in this type.
Corresponds to the JSON property oneofs
4253 4254 4255 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4253 def oneofs @oneofs end |
#options ⇒ Array<Google::Apis::ServiceconsumermanagementV1::Option>
The protocol buffer options.
Corresponds to the JSON property options
4258 4259 4260 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4258 def @options end |
#source_context ⇒ Google::Apis::ServiceconsumermanagementV1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
4264 4265 4266 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4264 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
4269 4270 4271 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4269 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4276 4277 4278 4279 4280 4281 4282 4283 4284 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4276 def update!(**args) @edition = args[:edition] if args.key?(:edition) @fields = args[:fields] if args.key?(:fields) @name = args[:name] if args.key?(:name) @oneofs = args[:oneofs] if args.key?(:oneofs) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |