Class: Google::Apis::ServiceconsumermanagementV1::Type

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Type

Returns a new instance of Type.



4262
4263
4264
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4262

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. Corresponds to the JSON property edition

Returns:

  • (String)


4229
4230
4231
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4229

def edition
  @edition
end

#fieldsArray<Google::Apis::ServiceconsumermanagementV1::Field>

The list of fields. Corresponds to the JSON property fields



4234
4235
4236
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4234

def fields
  @fields
end

#nameString

The fully qualified message name. Corresponds to the JSON property name

Returns:

  • (String)


4239
4240
4241
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4239

def name
  @name
end

#oneofsArray<String>

The list of types appearing in oneof definitions in this type. Corresponds to the JSON property oneofs

Returns:

  • (Array<String>)


4244
4245
4246
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4244

def oneofs
  @oneofs
end

#optionsArray<Google::Apis::ServiceconsumermanagementV1::Option>

The protocol buffer options. Corresponds to the JSON property options



4249
4250
4251
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4249

def options
  @options
end

#source_contextGoogle::Apis::ServiceconsumermanagementV1::SourceContext

SourceContext represents information about the source of a protobuf element, like the file in which it is defined. Corresponds to the JSON property sourceContext



4255
4256
4257
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4255

def source_context
  @source_context
end

#syntaxString

The source syntax. Corresponds to the JSON property syntax

Returns:

  • (String)


4260
4261
4262
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4260

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4267
4268
4269
4270
4271
4272
4273
4274
4275
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4267

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @fields = args[:fields] if args.key?(:fields)
  @name = args[:name] if args.key?(:name)
  @oneofs = args[:oneofs] if args.key?(:oneofs)
  @options = args[:options] if args.key?(:options)
  @source_context = args[:source_context] if args.key?(:source_context)
  @syntax = args[:syntax] if args.key?(:syntax)
end