Class: Google::Apis::ServiceconsumermanagementV1::Type

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Type

Returns a new instance of Type.



4264
4265
4266
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. Corresponds to the JSON property edition

Returns:

  • (String)


4231
4232
4233
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4231

def edition
  @edition
end

#fieldsArray<Google::Apis::ServiceconsumermanagementV1::Field>

The list of fields. Corresponds to the JSON property fields



4236
4237
4238
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4236

def fields
  @fields
end

#nameString

The fully qualified message name. Corresponds to the JSON property name

Returns:

  • (String)


4241
4242
4243
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4241

def name
  @name
end

#oneofsArray<String>

The list of types appearing in oneof definitions in this type. Corresponds to the JSON property oneofs

Returns:

  • (Array<String>)


4246
4247
4248
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4246

def oneofs
  @oneofs
end

#optionsArray<Google::Apis::ServiceconsumermanagementV1::Option>

The protocol buffer options. Corresponds to the JSON property options



4251
4252
4253
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4251

def options
  @options
end

#source_contextGoogle::Apis::ServiceconsumermanagementV1::SourceContext

SourceContext represents information about the source of a protobuf element, like the file in which it is defined. Corresponds to the JSON property sourceContext



4257
4258
4259
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4257

def source_context
  @source_context
end

#syntaxString

The source syntax. Corresponds to the JSON property syntax

Returns:

  • (String)


4262
4263
4264
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4262

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4269
4270
4271
4272
4273
4274
4275
4276
4277
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4269

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @fields = args[:fields] if args.key?(:fields)
  @name = args[:name] if args.key?(:name)
  @oneofs = args[:oneofs] if args.key?(:oneofs)
  @options = args[:options] if args.key?(:options)
  @source_context = args[:source_context] if args.key?(:source_context)
  @syntax = args[:syntax] if args.key?(:syntax)
end