Class: Google::Apis::ServiceconsumermanagementV1::V1AddVisibilityLabelsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Response message for the AddVisibilityLabels method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1AddVisibilityLabelsResponse

Returns a new instance of V1AddVisibilityLabelsResponse.



4393
4394
4395
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsArray<String>

The updated set of visibility labels for this consumer on this service. Corresponds to the JSON property labels

Returns:

  • (Array<String>)


4391
4392
4393
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4391

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4398
4399
4400
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4398

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
end