Class: Google::Apis::ServiceconsumermanagementV1::V1Beta1DisableConsumerResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Response message for the DisableConsumer method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1Beta1DisableConsumerResponse

Returns a new instance of V1Beta1DisableConsumerResponse.



4430
4431
4432
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4430

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4435
4436
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4435

def update!(**args)
end