Class: Google::Apis::ServiceconsumermanagementV1::V1Beta1RefreshConsumerResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Response message for the RefreshConsumer method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1Beta1RefreshConsumerResponse

Returns a new instance of V1Beta1RefreshConsumerResponse.



4658
4659
4660
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4658

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4663
4664
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4663

def update!(**args)
end