Class: Google::Apis::ServiceconsumermanagementV1::V1Beta1ServiceIdentity
- Inherits:
-
Object
- Object
- Google::Apis::ServiceconsumermanagementV1::V1Beta1ServiceIdentity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb
Overview
A service identity in the Identity and Access Management API.
Instance Attribute Summary collapse
-
#email ⇒ String
The email address of the service identity.
-
#name ⇒ String
P4 service identity resource name.
-
#project_role ⇒ String
The project-level IAM role defined in the service agent's grant configuration.
-
#tag ⇒ String
The P4 service identity configuration tag.
-
#unique_id ⇒ String
The unique and stable id of the service identity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ V1Beta1ServiceIdentity
constructor
A new instance of V1Beta1ServiceIdentity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ V1Beta1ServiceIdentity
Returns a new instance of V1Beta1ServiceIdentity.
4706 4707 4708 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4706 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email ⇒ String
The email address of the service identity.
Corresponds to the JSON property email
4676 4677 4678 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4676 def email @email end |
#name ⇒ String
P4 service identity resource name. An example name would be: services/
serviceconsumermanagement.googleapis.com/projects/123/serviceIdentities/
default
Corresponds to the JSON property name
4683 4684 4685 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4683 def name @name end |
#project_role ⇒ String
The project-level IAM role defined in the service agent's grant configuration.
This is the standard role intended for this service agent. This field is
populated regardless of the skip_role_attach option in the request. If
skip_role_attach is true, the caller can use this value to know which role
they are responsible for granting.
Corresponds to the JSON property projectRole
4692 4693 4694 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4692 def project_role @project_role end |
#tag ⇒ String
The P4 service identity configuration tag. This must be defined in
activation_grants. If not specified when creating the account, the tag is set
to "default".
Corresponds to the JSON property tag
4699 4700 4701 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4699 def tag @tag end |
#unique_id ⇒ String
The unique and stable id of the service identity.
Corresponds to the JSON property uniqueId
4704 4705 4706 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4704 def unique_id @unique_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4711 4712 4713 4714 4715 4716 4717 |
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4711 def update!(**args) @email = args[:email] if args.key?(:email) @name = args[:name] if args.key?(:name) @project_role = args[:project_role] if args.key?(:project_role) @tag = args[:tag] if args.key?(:tag) @unique_id = args[:unique_id] if args.key?(:unique_id) end |