Class: Google::Apis::ServiceconsumermanagementV1::V1GenerateDefaultIdentityResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Response message for the GenerateDefaultIdentity method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1GenerateDefaultIdentityResponse

Returns a new instance of V1GenerateDefaultIdentityResponse.



4813
4814
4815
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4813

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attach_statusString

Status of the role attachment. Under development (go/si-attach-role), currently always return ATTACH_STATUS_UNSPECIFIED) Corresponds to the JSON property attachStatus

Returns:

  • (String)


4800
4801
4802
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4800

def attach_status
  @attach_status
end

#identityGoogle::Apis::ServiceconsumermanagementV1::V1DefaultIdentity

A default identity in the Identity and Access Management API. Corresponds to the JSON property identity



4805
4806
4807
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4805

def identity
  @identity
end

#roleString

Role attached to consumer project. Empty if not attached in this request. ( Under development, currently always return empty.) Corresponds to the JSON property role

Returns:

  • (String)


4811
4812
4813
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4811

def role
  @role
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4818
4819
4820
4821
4822
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4818

def update!(**args)
  @attach_status = args[:attach_status] if args.key?(:attach_status)
  @identity = args[:identity] if args.key?(:identity)
  @role = args[:role] if args.key?(:role)
end