Class: Google::Apis::ServiceconsumermanagementV1::V1GenerateServiceAccountResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/serviceconsumermanagement_v1/classes.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb,
lib/google/apis/serviceconsumermanagement_v1/representations.rb

Overview

Response message for the GenerateServiceAccount method. This response message is assigned to the response field of the returned Operation when that operation is done.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ V1GenerateServiceAccountResponse

Returns a new instance of V1GenerateServiceAccountResponse.



4838
4839
4840
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4838

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accountGoogle::Apis::ServiceconsumermanagementV1::V1ServiceAccount

A service account in the Identity and Access Management API. Corresponds to the JSON property account



4836
4837
4838
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4836

def 
  @account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4843
4844
4845
# File 'lib/google/apis/serviceconsumermanagement_v1/classes.rb', line 4843

def update!(**args)
  @account = args[:account] if args.key?(:account)
end